@@ -410,7 +410,7 @@ class Profile(object):
             complemented_profiles = []
             for user_id, profiles_for_user in incomplete_users.items():
                 from_db_for_user = from_db.get(user_id, [])
-                if len(profiles_for_user) == 0:
+                if profiles_for_user is None or len(profiles_for_user) == 0:
                     if len(from_db_for_user) == 0:
                         missing_users.append(user_id)
                     else:
